summaryrefslogtreecommitdiffstats
path: root/lib/private/TemplateLayout.php
diff options
context:
space:
mode:
Diffstat (limited to 'lib/private/TemplateLayout.php')
-rw-r--r--lib/private/TemplateLayout.php3
1 files changed, 2 insertions, 1 deletions
diff --git a/lib/private/TemplateLayout.php b/lib/private/TemplateLayout.php
index c378396c727..5e6719593a3 100644
--- a/lib/private/TemplateLayout.php
+++ b/lib/private/TemplateLayout.php
@@ -131,10 +131,11 @@ class TemplateLayout extends \OC_Template {
parent::__construct('core', 'layout.base');
}
// Send the language to our layouts
$lang = \OC::$server->getL10NFactory()->findLanguage();
$lang = str_replace('_', '-', $lang);
$this->assign('language', $lang);
+ $this->assign('locale', \OC::$server->getL10NFactory()->findLocale($lang));
if(\OC::$server->getSystemConfig()->getValue('installed', false)) {
if (empty(self::$versionHash)) {
@@ -131,10 +131,11 @@ class TemplateLayout extends \OC_Template {
parent::__construct('core', 'layout.base');
}
- // Send the language to our layouts
+ // Send the language and the locale to our layouts
$lang = \OC::$server->getL10NFactory()->findLanguage();
$lang = str_replace('_', '-', $lang);